begin
;************************************************
; open file and read in data
;************************************************
; prepare input with cdo:
; cdo ml2pl,100,500,1000,2000,3000,5000,7000,8000,8500,9000,9500,10000,12500,15000,17500,20000,22500,25000,27500,30000,40000,50000,60000,70000,80000,85000,92500,100000 lc1_initialcondition_CTL_r10x360_with_ps.nc lc1_initialcondition_CTL.pl.nc

  DataFileName = "lc1_initialcondition_CTL.pl.nc"
  in  = addfile(DataFileName,"r")
  t   = in->T(0,:,:,0)
  lev = in->plev(:)
  lat = in->lat(:)

  printVarSummary(t)

;************************************************
; calculate tropopause
;************************************************
  ; Invert variables, pressure must be monotonically *increasing*
  ; which is not the case in MPI-ESM1-2-LR
  ;t_trans = transpose(t(::-1,:))
  ;lev_trans = lev(::-1)
  ;printVarSummary(t_trans)

  ; The order of the dimensions is different from what trop_wmo is
  ; expecting -> change the dimension to (lat,lev) instead of 
  ; (lev,lat)
  ;ptrop = trop_wmo(lev_trans, t_trans(lat|:,plev|:), 1, False)
  ptrop = trop_wmo(lev, t(lat|:,plev|:), 1, False)

  ;print(ptrop)

  ptrop!0      ="lat"
;  ptrop!1      ="lon"
  ptrop&lat    = t&lat
;  ptrop&lon    = t&lon
  printVarSummary(ptrop)
;************************************************
; save to netcdf file
;************************************************
  system("/bin/rm -f lc1_initialcondition_CTL_tropopause_zm.nc") ; remove any pre-existing file
  ncdf = addfile("lc1_initialcondition_CTL_tropopause_zm.nc" ,"c")  ; open output netCDF file

  ;===================================================================
  ; make time an UNLIMITED dimension; recommended  for most applications
  ;===================================================================
  filedimdef(ncdf,"time",-1,True)

  ;===================================================================
  ; output variables directly; NCL will call appropriate functions
  ; to write the meta data associated with each variable
  ;===================================================================
  ncdf->ptrop  = ptrop
end
